@@ -1,7 +1,7 @@
 import time
 
 from notecoin.database.base import Base, BaseTable, session
-from sqlalchemy import BIGINT, INTEGER, Column, Float, String
+from sqlalchemy import BIGINT, Integer, Column, Float, String
 
 
 class OkexSocketPublicTickers(Base, BaseTable):
@@ -9,24 +9,24 @@ class OkexSocketPublicTickers(Base, BaseTable):
     instType = Column(String(120), comment='产品类型', primary_key=True)
     instId = Column(String(120), comment='产品ID', primary_key=True)
 
-    last = Column(Float(), comment='最新成交价')
-    lastSz = Column(Float(), comment='最新成交的数量')
+    last = Column(Float, comment='最新成交价')
+    lastSz = Column(Float, comment='最新成交的数量')
 
-    askPx = Column(Float(), comment='卖一价')
-    askSz = Column(Float(), comment='卖一价对应的量')
-    bidPx = Column(Float(), comment='买一价')
-    bidSz = Column(Float(), comment='买一价对应的量')
+    askPx = Column(Float, comment='卖一价')
+    askSz = Column(Float, comment='卖一价对应的量')
+    bidPx = Column(Float, comment='买一价')
+    bidSz = Column(Float, comment='买一价对应的量')
 
-    open24h = Column(Float(), comment='24小时开盘价')
-    high24h = Column(Float(), comment='24小时最高价')
-    low24h = Column(Float(), comment='24小时最低价')
-    volCcy24h = Column(Float(), comment='24小时成交量，以计价货币为单位')
-    vol24h = Column(Float(), comment='24小时成交量，以交易货币为单位')
+    open24h = Column(Float, comment='24小时开盘价')
+    high24h = Column(Float, comment='24小时最高价')
+    low24h = Column(Float, comment='24小时最低价')
+    volCcy24h = Column(Float, comment='24小时成交量，以计价货币为单位')
+    vol24h = Column(Float, comment='24小时成交量，以交易货币为单位')
 
-    sodUtc0 = Column(Float(), comment='UTC 0时开盘价')
-    sodUtc8 = Column(Float(), comment='UTC+8时开盘价')
+    sodUtc0 = Column(Float, comment='UTC 0时开盘价')
+    sodUtc8 = Column(Float, comment='UTC+8时开盘价')
 
-    ts = Column(BIGINT(), comment='数据产生时间，Unix时间戳的毫秒数格式')
+    ts = Column(BIGINT, comment='数据产生时间，Unix时间戳的毫秒数格式')
 
     def __init__(self, *args, **kwargs):
         self.instType = kwargs.get("instType", "SPOT")
@@ -77,15 +77,16 @@ class OkexWebsocketChannels(Base, BaseTable):
             return {"delete success"}
         except Exception as e:
             session.rollback()
+            session.commit()
             return {"delete error": str(e)}
 
 
 class OkexWebsocketResponse(Base, BaseTable):
     __tablename__ = 'okex_websocket_response'
-    id = Column(INTEGER(), comment='id', autoincrement=True, primary_key=True)
+    id = Column(Integer, comment='id', autoincrement=True, primary_key=True)
     channel = Column(String(20), comment='channel')
     response = Column(String(2000), comment='response')
-    updateTime = Column(BIGINT(), comment='updateTime')
+    updateTime = Column(Integer, comment='updateTime')
 
     def __init__(self, *args, **kwargs):
         self.channel = kwargs.get("channel")
